@@ -2,5 +2,4 @@ pub mod current_src;
 pub mod path;
 pub mod archive;
 pub mod list;
-pub mod remove_hash_dir;
-
+pub mod apply_items;
